# pedhosp

<pre>
The goal of this program is to visualize the number of pedeatric COVID-19 
hospitalizations from Aug 8, 2020 to June 15, 2024 in the US.
To install pedhosp, use pip command.
$ pip install pedhosp
  
To display a graph of the result, run the following command:
$ pedhosp
</pre>

<img src='https://github.com/y-takefuji/pedhosp/raw/main/pediatric.png' height=360 width=600>
